@@ -85,7 +85,8 @@ def write_kafka_stream(stream: DataFrame, spark_job_conf: dict, output_name):
             .options(**output_conf['kafka_options']) \
             .trigger(availableNow=output_conf['availableNow']) \
             .outputMode("append") \
-            .start()
+            .start() \
+            .awaitTermination()
     else:
         stream \
             .writeStream \
@@ -186,7 +187,8 @@ def write_delta_stream(spark_job_conf: dict, output_name: str, stream: DataFrame
         .trigger(availableNow=True) \
         .partitionBy(output_stream_conf['delta_options']['partition_columns']) \
         .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
-        .start(output_stream_conf['delta_options']['location'])
+        .start(output_stream_conf['delta_options']['location']) \
+        .awaitTermination()
 
 
 def write_delta_stream_no_partitioning(spark_job_conf: dict, output_name: str, stream: DataFrame):
